//    sealed class LoadResult<Key : Any, Value : Any> {
//         /**
//          * Error result object for [PagingSource.load].
//          *
//          * This return type indicates an expected, recoverable error (such as a network load
//          * failure). This failure will be forwarded to the UI as a [LoadState.Error], and may be
//          * retried.
//          *
//          * @sample androidx.paging.samples.pageKeyedPagingSourceSample
//          */
//         data class Error<Key : Any, Value : Any>(
//             val throwable: Throwable
//         ) : LoadResult<Key, Value>()
//
//         /**
//          * Success result object for [PagingSource.load].
//          *
//          * @sample androidx.paging.samples.pageKeyedPage
//          * @sample androidx.paging.samples.pageIndexedPage
//          */
//         data class Page<Key : Any, Value : Any> constructor(
//             /**
//              * Loaded data
//              */
//             val data: List<Value>,
//             /**
//              * [Key] for previous page if more data can be loaded in that direction, `null`
//              * otherwise.
//              */
//             val prevKey: Key?,
//             /**
//              * [Key] for next page if more data can be loaded in that direction, `null` otherwise.
//              */
//             val nextKey: Key?,
//             /**
//              * Optional count of items before the loaded data.
//              */
//             @IntRange(from = COUNT_UNDEFINED.toLong())
//             val itemsBefore: Int = COUNT_UNDEFINED,
//             /**
//              * Optional count of items after the loaded data.
//              */
//             @IntRange(from = COUNT_UNDEFINED.toLong())
//             val itemsAfter: Int = COUNT_UNDEFINED
//         ) : LoadResult<Key, Value>() {
//
//             /**
//              * Success result object for [PagingSource.load].
//              *
//              * @param data Loaded data
//              * @param prevKey [Key] for previous page if more data can be loaded in that direction,
//              * `null` otherwise.
//              * @param nextKey [Key] for next page if more data can be loaded in that direction,
//              * `null` otherwise.
//              */
//             constructor(
//                 data: List<Value>,
//                 prevKey: Key?,
//                 nextKey: Key?
//             ) : this(data, prevKey, nextKey, COUNT_UNDEFINED, COUNT_UNDEFINED)
//
//             init {
//                 require(itemsBefore == COUNT_UNDEFINED || itemsBefore >= 0) {
//                     "itemsBefore cannot be negative"
//                 }
//
//                 require(itemsAfter == COUNT_UNDEFINED || itemsAfter >= 0) {
//                     "itemsAfter cannot be negative"
//                 }
//             }
//
//             companion object {
//                 const val COUNT_UNDEFINED = Int.MIN_VALUE
//
//                 @Suppress("MemberVisibilityCanBePrivate") // Prevent synthetic accessor generation.
//                 internal val EMPTY = Page(emptyList(), null, null, 0, 0)
//
//                 @Suppress("UNCHECKED_CAST") // Can safely ignore, since the list is empty.
//                 internal fun <Key : Any, Value : Any> empty() = EMPTY as Page<Key, Value>
//             }
//         }
//     }

// /// Result of a load request from [PagingSource.load].
// @freezed
// class LoadResult<Key, Value> with _$LoadResult<Key, Value> {
//   /// Error result object for [PagingSource.load].
//   ///
//   /// This return type indicates an expected, recoverable error (such as a network load
//   /// failure). This failure will be forwarded to the UI as a [LoadState.Error], and may be
//   /// retried.
//   const factory LoadResult.error(Exception e) = Error<Key, Value>;
//
//   /// Success result object for [PagingSource.load].
//   const factory LoadResult.page({
//     required List<Value> data,
//     Key? prevKey,
//     Key? nextKey,
//     @Default(countUndefined)
//     @Assert(
//       'itemsBefore == countUndefined || itemsBefore >= 0',
//       'itemsBefore cannot be negative',
//     )
//         int itemsBefore,
//     @Default(countUndefined)
//     @Assert(
//       'itemsAfter == countUndefined || itemsAfter >= 0',
//       'itemsAfter cannot be negative',
//     )
//         int itemsAfter,
//   }) = Page<Key, Value>;
//
//   factory LoadResult.empty() => LoadResult.page(
//         data: [],
//         itemsBefore: 0,
//         itemsAfter: 0,
//       );
// }
